# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
from django import forms

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
try:
    from djangocms_text_ckeditor.fields import HTMLFormField
except ImportError:
    HTMLFormField = None

from .models import TopBanner


class TopBannerForm(forms.ModelForm):
    if HTMLFormField:
        body = TopBanner._meta.get_field('body').formfield(
            widget=None,
            form_class=HTMLFormField,
        )

    class Meta:
        model = TopBanner
        fields = [
            'title',
            'subtitle',
            'body',
            'background',
            'foreground',
            'extra_image',
            'css_classes',
        ]


class TopBannerPlugin(CMSPluginBase):
    model = TopBanner
    name = _('Top Banner plugin')
    render_template = 'topbanner_cmsplugin/banner.html'
    cache = True
    form = TopBannerForm

    def render(self, context, instance, placeholder):
        context.update({
            'banner': instance,
        })
        return context


plugin_pool.register_plugin(TopBannerPlugin)
